import {Component, OnInit} from '@angular/core';
import {JtrService} from "../jtr.service";
import {InputOutputComponent} from "../input-output/input-output.component";
import {
  DebounceTime,
  GenerateDefaultJsonObjectString,
  MonacoJsonConfig,
  ReadOnlyMonacoJsonConfig
} from "../defaults";
import {debounceTime, BehaviorSubject} from "rxjs";

@Component({
  selector: 'app-uglify',
  standalone: true,
  imports: [
    InputOutputComponent
  ],
  templateUrl: './uglify.component.html',
  styleUrl: './uglify.component.scss'
})
export class UglifyComponent implements OnInit {
  // input: string = ;
  $input: BehaviorSubject<string> = new BehaviorSubject<string>(GenerateDefaultJsonObjectString(2));
  inputOptions = MonacoJsonConfig;
  output: string = GenerateDefaultJsonObjectString();
  outputOptions = ReadOnlyMonacoJsonConfig;

  constructor(private service: JtrService) {
  }

  ngOnInit(): void {
    this.$input
      .pipe(debounceTime(DebounceTime))
      .subscribe(input => {
        this.update(input)
      });
  }

  update(input: string): void {
    this.service
      .uglify(input)
      .subscribe({
        next: response => {
          console.log(response);
          this.output = response.body.result;
        },
        error: response => {
          console.log(response)
          if (response.status === 499) {
            this.output = response.error.detail;
            console.log(response.error.detail);
          }
        }
      });
  }

  handleInputChange($event: any): void {
    console.log($event);
    this.$input.next($event);
  }
}
